@@ -4,8 +4,8 @@ context("SAMC test")
 test_that("samc p matrix row sums equal 1 without fidelity data", {
 
   # Create the samc object and get the row sums of the p matrix
-  samc_obj <- samc(testlist[[1]]$res, testlist[[1]]$abs, tr_fun = function(x) 1/mean(x))
-  rs <- Matrix::rowSums(samc_obj@p)
+  samc_obj <- samc(testlist[[1]]$res, testlist[[1]]$abs, tr_args = list(fun = function(x) 1/mean(x), dir = 8, sym = TRUE))
+  rs <- Matrix::rowSums(samc_obj$p_matrix)
 
   # Create a vector of the expected result based on the number of non-NA cells
   # in the original data and an extra entry for the last row of the p matrix
@@ -20,8 +20,8 @@ test_that("samc p matrix row sums equal 1 without fidelity data", {
 test_that("samc p matrix row sums equal 1 with fidelity data", {
 
   # Create the samc object and get the row sums of the p matrix
-  samc_obj <- samc(testlist[[1]]$res, testlist[[1]]$abs, testlist[[1]]$fid, tr_fun = function(x) 1/mean(x))
-  rs <- Matrix::rowSums(samc_obj@p)
+  samc_obj <- samc(testlist[[1]]$res, testlist[[1]]$abs, testlist[[1]]$fid, tr_args = list(fun = function(x) 1/mean(x), dir = 8, sym = TRUE))
+  rs <- Matrix::rowSums(samc_obj$p_matrix)
 
   # Create a vector of the expected result based on the number of non-NA cells
   # in the original data and an extra entry for the last row of the p matrix
